@@ -273,13 +273,13 @@ class VTECProduct(TextProduct):
             f"INSERT into {sbw_table} (wfo, eventid, "
             "significance, phenomena, issue, expire, init_expire, "
             "polygon_begin, polygon_end, geom, status, report, windtag, "
-            "hailtag, tornadotag, tornadodamagetag, tml_valid, "
-            f"tml_direction, tml_sknt, {tml_column}, updated, "
+            "hailtag, tornadotag, damagetag, "
+            f"tml_valid, tml_direction, tml_sknt, {tml_column}, updated, "
             "waterspouttag, is_emergency, is_pds, floodtag_heavyrain, "
             "floodtag_flashflood, floodtag_damage, floodtag_leeve, "
             "floodtag_dam, hvtec_nwsli, hvtec_severity, hvtec_cause, "
-            "hvtec_record) "
-            "VALUES (%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,"
+            "hvtec_record, windthreat, hailthreat) "
+            "VALUES (%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,"
             "%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s)"
         )
         myargs = (
@@ -298,7 +298,7 @@ class VTECProduct(TextProduct):
             segment.windtag,
             segment.hailtag,
             segment.tornadotag,
-            segment.tornadodamagetag,
+            segment.damagetag,
             tml_valid,
             segment.tml_dir,
             segment.tml_sknt,
@@ -316,6 +316,8 @@ class VTECProduct(TextProduct):
             segment.get_hvtec_severity(),
             segment.get_hvtec_cause(),
             segment.get_hvtec_record(),
+            segment.windthreat,
+            segment.hailthreat,
         )
         txn.execute(sql, myargs)
 
