@@ -27,32 +27,27 @@ import pickle
 import datetime
 import warnings
 
-#
+# third party
+import rasterio
+from rasterio.warp import reproject, Resampling
 import requests
 import numpy as np
 import pandas as pd
 import geopandas as gpd
 from shapely.geometry import shape
-
-#
 from scipy.signal import convolve2d
 from scipy.interpolate import NearestNDInterpolator
-
-#
 from PIL import Image
-
-# Matplotlib
 from matplotlib.patches import Polygon
 import matplotlib.colors as mpcolors
 from matplotlib.patches import Wedge
 import matplotlib.colorbar as mpcolorbar
 import matplotlib.patheffects as PathEffects
-
-# cartopy
 import cartopy
 import cartopy.crs as ccrs
 import cartopy.feature as cfeature
 
+# local
 from pyiem.plot.use_agg import plt
 from pyiem.plot.util import (
     sector_setter,
@@ -74,7 +69,7 @@ from pyiem.reference import (  # noqa: F401  # pylint: disable=unused-import
     Z_FRAME,
     TWITTER_RESOLUTION_INCH,
 )
-from pyiem.util import ssw, LOG
+from pyiem.util import ssw, LOG, utc, exponential_backoff
 from pyiem.datatypes import speed, direction
 from pyiem.plot.colormaps import stretch_cmap
 import pyiem.meteorology as meteorology
@@ -655,7 +650,7 @@ class MapPlot:
         labelbuffer=25,
         outlinecolor="#FFFFFF",
         zorder=None,
-        **kwargs
+        **kwargs,
     ):
         """Plot values onto the map
 
@@ -982,6 +977,10 @@ class MapPlot:
             s = load_pickle_geo("cwa.pickle")
             mask_outside_geom(self.ax, s[self.cwa]["geom"])
             return
+        if sector == "conus":
+            s = load_pickle_geo("conus.pickle")
+            mask_outside_geom(self.ax, s["conus"]["geom"])
+            return
         if sector == "iowawfo":
             s = load_pickle_geo("iowawfo.pickle")
             geo = s["iowawfo"]["geom"]
@@ -1016,17 +1015,37 @@ class MapPlot:
             ll = ccrs.Geodetic().transform_point(
                 xbnds[0], ybnds[0], self.ax.projection
             )
+            cl = ccrs.Geodetic().transform_point(
+                xbnds[0], sum(ybnds) / 2, self.ax.projection
+            )
             ul = ccrs.Geodetic().transform_point(
                 xbnds[0], ybnds[1], self.ax.projection
             )
+            uc = ccrs.Geodetic().transform_point(
+                sum(xbnds) / 2, ybnds[1], self.ax.projection
+            )
             ur = ccrs.Geodetic().transform_point(
                 xbnds[1], ybnds[1], self.ax.projection
             )
+            cr = ccrs.Geodetic().transform_point(
+                xbnds[1], sum(ybnds) / 2, self.ax.projection
+            )
             lr = ccrs.Geodetic().transform_point(
                 xbnds[1], ybnds[0], self.ax.projection
             )
-            xi = np.linspace(min(ll[0], ul[0]), max(lr[0], ur[0]), 100)
-            yi = np.linspace(min(ll[1], ul[1]), max(ul[1], ur[1]), 100)
+            lc = ccrs.Geodetic().transform_point(
+                sum(xbnds) / 2, ybnds[0], self.ax.projection
+            )
+            xi = np.linspace(
+                min(ll[0], cl[0], ul[0]),
+                max(lr[0], cr[0], ur[0]),
+                100,
+            )
+            yi = np.linspace(
+                min(ll[1], lc[1], lr[1]),
+                max(ul[1], uc[1], ur[1]),
+                100,
+            )
             xi, yi = np.meshgrid(xi, yi)
             nn = NearestNDInterpolator((lons, lats), vals)
             vals = nn(xi, yi)
@@ -1090,19 +1109,20 @@ class MapPlot:
         clidict = load_pickle_geo("climdiv.pickle")
         polygon_fill(self, clidict, data, **kwargs)
 
-    def fill_ugcs(self, data, bins=None, color=None, **kwargs):
+    def fill_ugcs(
+        self, data, bins=None, color=None, is_firewx=False, **kwargs
+    ):
         """Overlay filled UGC geometries
 
-        The logic for plotting is a bit tricky due to fire zones overlapping
-        forecast zones.  In general, provide the zone code if you want it to
-        display on top.  Otherwise, I attempt to place forecast zones overtop
-        fire weather zones.
+        Note the importance of the `is_firewx` flag.  This determines which
+        UGC database to look at in the face of ambiquity.
 
         Args:
           data(dict): A dictionary of 6 char UGC code keys and values
           bins(list, optional): Bins to use for cloropleth, default 0:101:10
           color(dict, optional): Hard code what each UGC should display as
             for color.
+          is_firewx(bool, optional): Are we plotting fire weather zones?
           nocbar (bool, optional): Should a color bar be generated, default is
             `True`.
           plotmissing(bool, optional): Should missing UGC data be plotted?
@@ -1122,8 +1142,9 @@ class MapPlot:
             if key[2] == "Z":
                 counties = False
             break
+        zonesfn = "firewx" if is_firewx else "zone"
         ugcs = load_pickle_geo(
-            "ugcs_county.pickle" if counties else "ugcs_zone.pickle"
+            "ugcs_county.pickle" if counties else f"ugcs_{zonesfn}.pickle"
         )
         if color is None:
             color = dict()
@@ -1143,10 +1164,6 @@ class MapPlot:
             if data.get(ugc) is None:
                 if not plotmissing:
                     continue
-                # Holy cow, it appears values above 300 are always firewx,
-                # so lets ignore these when we have no data!
-                if not counties and int(ugc[3:]) >= 300:
-                    continue
                 c = "white"
                 val = kwargs.get("missingval", "-")
                 z = Z_OVERLAY
@@ -1219,7 +1236,7 @@ class MapPlot:
                 crs=ccrs.PlateCarree(),
                 zorder=Z_POLITICAL,
                 facecolor="None",
-                **kwargs
+                **kwargs,
             )
 
     def fill_cwas(self, data, **kwargs):
@@ -1284,7 +1301,7 @@ class MapPlot:
             df2.name.values,
             showmarker=True,
             textsize=tsz,
-            **kwargs
+            **kwargs,
         )
 
     def drawcounties(self, color="k"):
@@ -1350,6 +1367,158 @@ class MapPlot:
             shutil.copyfile(tmpfd.name, kwargs.get("filename"))
         os.unlink(tmpfd.name)
 
+    def overlay_roadcond(self, valid=None):
+        """Overlay Iowa Winter Road Conditions.
+
+        Args:
+          valid (datetime.datetime): Valid time for NEXRAD overlay.
+        """
+        if valid is None:
+            valid = utc()
+        if hasattr(valid, "tzinfo"):
+            valid = valid.astimezone(datetime.timezone.utc)
+        url = (
+            "https://mesonet.agron.iastate.edu/"
+            "api/1/iowa_winter_roadcond.geojson"
+        )
+        tstamp = valid.strftime("%Y-%m-%d %H:%M")
+        try:
+            req = requests.get(url, params={"valid": tstamp}, timeout=30)
+        except requests.ConnectionError as exp:
+            warnings.warn("overlay_roadcond failed: %s" % (exp,))
+            return None
+        df = gpd.GeoDataFrame().from_features(req.json())
+        labels = []
+        for _, row in df.iterrows():
+            for geo in row["geometry"]:
+                self.ax.plot(
+                    *geo.xy,
+                    transform=ccrs.PlateCarree(),
+                    color=row["color"],
+                    linewidth=2 if row["rtype"] > 1 else 4,
+                    zorder=Z_OVERLAY2,
+                    label=None if row["label"] in labels else row["label"],
+                )
+                if row["label"] not in labels:
+                    labels.append(row["label"])
+        self.ax.legend(
+            loc=3,
+            ncol=6,
+            fontsize=10,
+            facecolor="white",
+            framealpha=1,
+        ).set_zorder(Z_OVERLAY2 + 5)
+
+    def overlay_nexrad(self, valid=None, product="N0Q"):
+        """Overlay an IEM NEXRAD Composite Image.
+
+        Args:
+          valid (datetime.datetime): Valid time for NEXRAD overlay.
+          product (str): either N0Q or N0R for the mosaic type.
+
+        Returns:
+          valid time of the NEXRAD, or None if not found.
+        """
+        if valid is None:
+            valid = utc()
+        if hasattr(valid, "tzinfo"):
+            valid = valid.astimezone(datetime.timezone.utc)
+        if product not in ["N0R", "N0Q"]:
+            raise ValueError("nexrad `product` not in {N0R,N0Q}")
+        # Rectify to modulus 5 minutes
+        valid -= datetime.timedelta(minutes=(valid.minute % 5))
+        compsector = "us"
+        if self.sector == "state" and self.state in ["AK", "HI", "PR"]:
+            compsector = self.state.lower()
+        elif self.sector == "cwa" and self.cwa in ["AFG", "AJK", "AFC"]:
+            compsector = "ak"
+        elif self.sector == "cwa" and self.cwa in [
+            "HFO",
+        ]:
+            compsector = "hi"
+        elif self.sector == "cwa" and self.cwa in [
+            "SJU",
+        ]:
+            compsector = "pr"
+        baseurl = valid.strftime(
+            "https://mesonet.agron.iastate.edu/archive/data/%Y/%m/%d/"
+            f"GIS/{compsector}comp/{product.lower()}_%Y%m%d%H%M."
+        )
+        req_png = exponential_backoff(
+            requests.get, baseurl + "png", timeout=10
+        )
+        req_wld = exponential_backoff(
+            requests.get, baseurl + "wld", timeout=10
+        )
+        if req_png is None or req_png.status_code != 200:
+            LOG.debug("Failed to fetch %spng", baseurl)
+            return None
+        if req_wld is None or req_wld.status_code != 200:
+            LOG.debug("Failed to fetch %swld", baseurl)
+            return None
+        (dx, _, _, dy, west, north) = [
+            float(x) for x in req_wld.content.decode("ascii").split("\n")
+        ]
+        bio = BytesIO(req_png.content)
+        bio.seek(0)
+        im = np.asarray(Image.open(bio))
+        # Use rasterio to reproject this grid into the projection of axes
+        with rasterio.Env():
+            src_aff = rasterio.Affine(dx, 0, west, 0, dy, north)
+            src_crs = {"init": "EPSG:4326"}
+            (px0, px1, py0, py1) = self.ax.get_extent()
+            pbbox = self.ax.get_window_extent()
+            pdx = (px1 - px0) / pbbox.width
+            pdy = (py1 - py0) / pbbox.height
+            dest_aff = rasterio.Affine(pdx, 0, px0, 0, pdy, py0)
+            res = np.zeros(
+                (int(pbbox.height), int(pbbox.width)), dtype=im.dtype
+            )
+            reproject(
+                im,
+                res,
+                src_transform=src_aff,
+                src_crs=src_crs,
+                src_nodata=0,
+                dst_transform=dest_aff,
+                dst_crs=self.ax.projection.proj4_params,
+                resampling=Resampling.nearest,
+            )
+
+        ramp = pd.read_csv(f"{DATADIR}/ramps/composite_{product.lower()}.txt")
+        cmap = mpcolors.ListedColormap(ramp[["r", "g", "b"]].to_numpy() / 256)
+        cmap.set_under((0, 0, 0, 0))
+        norm = mpcolors.BoundaryNorm(ramp["coloridx"].values, cmap.N)
+        self.ax.imshow(
+            res,
+            interpolation="nearest",  # prevents artifacts
+            extent=(px0, px1, py0, py1),
+            cmap=cmap,
+            norm=norm,
+            zorder=Z_FILL,
+            origin="lower",
+        ).set_rasterized(True)
+        pos = self.ax.get_position()
+        cax = self.fig.add_axes([pos.x1 - 0.35, pos.y1 - 0.01, 0.35, 0.015])
+        cb = mpcolorbar.ColorbarBase(
+            cax,
+            cmap=cmap,
+            norm=norm,
+            ticks=ramp.loc[ramp["value"] % 20 == 0]["coloridx"].values,
+            extend="neither",
+            orientation="horizontal",
+            drawedges=False,
+            ticklocation="top",
+        )
+        cb.set_ticklabels(
+            [
+                "%.0d" % (d,)
+                for d in ramp.loc[ramp["value"] % 20 == 0]["value"].values
+            ]
+        )
+        self.fig.text(pos.x1, pos.y1 + 0.005, "dBZ", ha="left")
+        return valid
+
 
 def windrose(*args, **kwargs):
     """Depreciated."""
