@@ -24,9 +24,9 @@ import cartopy.crs as ccrs
     Z_CF,
     Z_FILL,
     Z_FILL_LABEL,
-    Z_POLITICAL,
     Z_CLIP,
     Z_CLIP2,
+    Z_POLITICAL,
     Z_OVERLAY,
     Z_OVERLAY_LABEL,
     Z_OVERLAY2,
@@ -449,7 +449,7 @@ state_bounds = {
 #
 # with data as (
 #    select wfo, st_extent(geom) as ext from ugcs
-#    GROUP by wfo)
+#    where end_ts is null GROUP by wfo)
 # SELECT '"'||wfo||'": ['||
 # round((ST_xmin(ext) - 0.2)::numeric, 2) ||', '||
 # round((ST_ymin(ext) - 0.2)::numeric, 2) ||', '||
@@ -460,38 +460,38 @@ wfo_bounds = {
     "ABQ": [-109.25, 32.32, -102.80, 37.20],
     "ABR": [-102.20, 43.30, -95.90, 46.22],
     "AFC": [-179.35, 51.02, -139.81, 63.75],
-    "AFG": [-172.05, 61.02, -140.80, 71.59],
-    "AJK": [-144.10, 54.47, -129.78, 60.87],
-    "AKQ": [-78.94, 35.61, -74.85, 38.90],
+    "AFG": [-177.40, 61.02, -140.80, 74.91],
+    "AJK": [-144.22, 53.87, -129.78, 60.87],
+    "AKQ": [-78.94, 35.61, -74.11, 38.90],
     "ALY": [-75.42, 41.24, -72.23, 44.32],
     "AMA": [-103.24, 34.55, -99.80, 37.20],
-    "APX": [-86.59, 43.61, -82.99, 46.97],
+    "APX": [-87.17, 43.61, -82.06, 47.00],
     "ARX": [-93.25, 42.31, -89.40, 45.58],
     "BGM": [-77.95, 40.70, -74.16, 43.81],
     "BIS": [-104.25, 45.74, -97.81, 49.20],
     "BMX": [-88.62, 31.42, -84.69, 34.73],
-    "BOI": [-120.14, 41.79, -113.73, 45.47],
+    "BOI": [-120.31, 41.79, -113.73, 45.77],
     "BOU": [-107.07, 38.32, -101.85, 41.20],
-    "BOX": [-73.27, 40.95, -69.73, 43.09],
-    "BRO": [-99.65, 25.64, -96.93, 27.56],
+    "BOX": [-73.27, 40.27, -68.90, 43.11],
+    "BRO": [-99.65, 25.64, -95.79, 27.56],
     "BTV": [-76.04, 43.02, -71.27, 45.22],
-    "BUF": [-79.96, 41.80, -74.91, 44.60],
-    "BYZ": [-111.25, 44.36, -103.84, 47.06],
+    "BUF": [-80.05, 41.80, -74.67, 45.20],
+    "BYZ": [-111.80, 43.82, -102.74, 47.06],
     "CAE": [-82.85, 32.60, -79.58, 35.27],
-    "CAR": [-70.52, 43.88, -66.75, 47.66],
-    "CHS": [-82.45, 31.09, -79.07, 33.71],
-    "CLE": [-84.08, 40.04, -79.41, 42.47],
-    "CRP": [-100.41, 27.01, -96.12, 29.30],
+    "CAR": [-70.52, 43.30, -66.69, 47.66],
+    "CHS": [-82.45, 30.91, -78.43, 33.71],
+    "CLE": [-84.08, 40.04, -79.41, 42.68],
+    "CRP": [-100.41, 26.88, -95.34, 29.30],
     "CTP": [-79.81, 39.52, -75.56, 42.20],
     "CYS": [-108.13, 40.80, -102.41, 43.70],
     "DDC": [-102.24, 36.79, -98.15, 39.33],
-    "DLH": [-94.99, 45.18, -89.28, 48.91],
+    "DLH": [-94.99, 45.18, -89.21, 48.91],
     "DMX": [-95.87, 40.37, -91.86, 43.70],
-    "DTX": [-84.81, 41.51, -82.21, 44.27],
+    "DTX": [-84.81, 41.51, -81.92, 44.39],
     "DVN": [-92.61, 39.99, -88.96, 42.88],
     "EAX": [-95.97, 37.83, -92.09, 40.80],
-    "EKA": [-124.62, 38.56, -122.25, 42.20],
-    "EPZ": [-109.25, 30.43, -104.65, 33.68],
+    "EKA": [-126.01, 38.47, -122.14, 42.20],
+    "EPZ": [-109.25, 30.43, -104.61, 34.55],
     "EWX": [-101.96, 28.00, -96.36, 31.23],
     "FFC": [-85.80, 31.58, -81.80, 35.19],
     "FGF": [-100.05, 45.56, -94.21, 49.59],
@@ -502,78 +502,84 @@ wfo_bounds = {
     "GID": [-100.42, 38.93, -97.17, 41.94],
     "GJT": [-111.11, 36.79, -105.98, 41.20],
     "GLD": [-103.37, 38.06, -99.40, 40.64],
-    "GRB": [-90.52, 43.59, -86.61, 46.50],
-    "GRR": [-86.74, 41.87, -83.93, 44.38],
+    "GRB": [-90.52, 43.59, -86.09, 46.50],
+    "GRR": [-87.35, 41.87, -83.93, 44.48],
     "GSP": [-84.24, 33.75, -79.98, 36.49],
-    "GUM": [133.92, 5.06, 172.36, 20.75],
-    "GYX": [-72.76, 42.50, -68.34, 46.18],
-    "HFO": [-160.45, 18.71, -154.61, 22.44],
-    "HGX": [-97.16, 28.18, -94.15, 31.79],
+    "GUM": [132.01, 4.48, 172.36, 20.75],
+    "GYX": [-72.76, 42.50, -68.26, 46.18],
+    "HFO": [-161.12, 18.05, -153.95, 23.10],
+    "HGX": [-97.16, 27.46, -93.81, 31.79],
     "HNX": [-121.45, 34.59, -117.42, 38.38],
+    "HPA": [-164.45, 14.72, -150.61, 26.44],
     "HUN": [-88.40, 33.66, -85.31, 35.61],
     "ICT": [-99.24, 36.80, -94.87, 39.42],
-    "ILM": [-80.49, 32.92, -77.32, 35.15],
+    "ILM": [-80.49, 32.60, -76.77, 35.15],
     "ILN": [-85.64, 38.12, -81.96, 41.02],
     "ILX": [-91.11, 38.37, -87.30, 41.43],
     "IND": [-87.96, 38.21, -84.60, 40.94],
     "IWX": [-87.30, 40.11, -83.68, 42.44],
     "JAN": [-92.34, 30.71, -88.05, 34.32],
-    "JAX": [-83.51, 28.76, -80.90, 32.17],
+    "JAX": [-83.51, 28.76, -79.78, 32.17],
     "JKL": [-85.26, 36.38, -81.77, 38.72],
-    "KEY": [-83.13, 24.32, -80.06, 25.55],
+    "KEY": [-83.49, 23.32, -79.34, 25.80],
     "LBF": [-102.99, 40.15, -98.10, 43.20],
-    "LCH": [-94.93, 29.13, -90.87, 31.72],
-    "LIX": [-92.02, 28.72, -88.19, 31.57],
+    "LCH": [-94.93, 27.89, -90.88, 31.72],
+    "LIX": [-92.02, 27.72, -87.74, 31.57],
     "LKN": [-119.53, 37.84, -113.84, 42.20],
     "LMK": [-87.34, 36.41, -83.63, 39.12],
-    "LOT": [-89.89, 40.20, -86.73, 42.70],
-    "LOX": [-121.55, 32.60, -117.45, 36.00],
+    "LOT": [-89.89, 40.20, -86.70, 42.70],
+    "LOX": [-123.09, 32.60, -117.40, 36.00],
     "LSX": [-93.04, 36.85, -88.49, 40.50],
     "LUB": [-103.26, 32.76, -99.79, 34.95],
-    "LWX": [-80.01, 37.34, -75.86, 39.92],
-    "LZK": [-94.67, 32.96, -90.67, 36.70],
-    "MAF": [-105.18, 28.77, -100.46, 33.77],
-    "MEG": [-91.61, 33.45, -87.72, 36.83],
-    "MFL": [-82.05, 24.92, -79.83, 27.41],
-    "MFR": [-124.81, 40.79, -119.16, 44.15],
-    "MHX": [-78.40, 34.24, -75.26, 36.43],
-    "MKX": [-90.63, 42.29, -87.50, 44.18],
-    "MLB": [-82.16, 26.76, -79.88, 29.63],
-    "MOB": [-89.54, 30.02, -85.94, 32.51],
+    "LWX": [-80.01, 37.34, -75.57, 39.92],
+    "LZK": [-94.67, 32.96, -90.55, 36.70],
+    "MAF": [-105.55, 28.77, -100.46, 34.30],
+    "MEG": [-91.35, 33.45, -87.72, 36.83],
+    "MFL": [-83.12, 24.40, -78.83, 27.41],
+    "MFR": [-126.25, 40.79, -119.04, 44.23],
+    "MHX": [-78.40, 33.71, -74.59, 36.43],
+    "MKX": [-90.63, 42.26, -86.82, 44.18],
+    "MLB": [-82.16, 26.76, -78.85, 29.68],
+    "MOB": [-89.54, 29.00, -85.78, 32.51],
     "MPX": [-96.65, 43.30, -90.48, 46.57],
-    "MQT": [-90.62, 44.89, -85.04, 48.39],
+    "MQT": [-90.64, 44.89, -83.27, 48.51],
     "MRX": [-86.07, 34.78, -81.41, 37.40],
-    "MSO": [-116.99, 44.03, -111.99, 49.20],
-    "MTR": [-123.73, 35.59, -120.01, 39.06],
+    "MSO": [-117.26, 44.03, -111.15, 49.20],
+    "MTR": [-125.31, 35.45, -120.01, 39.15],
+    "NH1": [-120.67, -3.64, -76.81, 32.73],
+    "NH2": [-98.09, 6.79, -54.78, 31.21],
     "OAX": [-98.51, 39.80, -94.71, 43.08],
-    "OHX": [-88.27, 34.79, -84.46, 36.88],
-    "OKX": [-74.96, 40.30, -71.59, 41.91],
-    "OTX": [-121.38, 45.66, -114.76, 49.20],
+    "OHX": [-88.58, 34.79, -84.46, 36.88],
+    "OKX": [-74.96, 39.69, -71.19, 41.91],
+    "ONA": [-80.72, 30.79, -64.79, 44.37],
+    "ONP": [-131.31, 28.80, -116.31, 48.72],
+    "OTX": [-121.72, 45.66, -114.76, 49.20],
     "OUN": [-100.25, 33.20, -95.47, 37.20],
-    "PAH": [-91.42, 36.14, -86.57, 38.81],
+    "PAH": [-91.88, 36.14, -86.57, 38.81],
     "PBZ": [-82.43, 38.76, -78.51, 41.83],
-    "PDT": [-122.20, 43.41, -116.26, 47.80],
-    "PHI": [-76.64, 38.25, -73.77, 41.56],
-    "PIH": [-115.51, 41.79, -110.84, 45.08],
+    "PDT": [-122.35, 43.06, -116.26, 47.80],
+    "PHI": [-76.64, 38.02, -73.10, 41.56],
+    "PIH": [-115.51, 41.79, -110.56, 45.91],
     "PPG": [-171.25, -14.57, -169.22, -10.88],
-    "PQR": [-124.36, 43.24, -121.24, 46.99],
+    "PQR": [-125.90, 43.15, -121.21, 46.99],
     "PSR": [-116.67, 31.84, -109.80, 34.52],
     "PUB": [-107.35, 36.79, -101.84, 39.58],
     "RAH": [-80.72, 34.35, -77.03, 36.74],
     "REV": [-121.53, 37.26, -117.10, 42.20],
-    "RIW": [-111.35, 40.80, -105.81, 45.31],
+    "RIW": [-111.35, 40.79, -105.81, 45.31],
     "RLX": [-83.54, 36.76, -79.15, 40.13],
     "RNK": [-82.12, 35.80, -78.04, 38.47],
-    "SEW": [-124.96, 46.18, -120.45, 49.20],
+    "SEW": [-126.52, 46.12, -120.45, 49.20],
     "SGF": [-95.29, 36.30, -90.82, 38.89],
-    "SGX": [-118.31, 32.34, -115.75, 35.02],
+    "SGX": [-118.91, 32.23, -115.75, 35.02],
     "SHV": [-95.87, 30.83, -91.67, 34.71],
     "SJT": [-102.58, 30.09, -98.21, 33.60],
-    "SJU": [-68.15, 17.47, -64.37, 18.72],
+    "SJU": [-68.20, 16.80, -63.80, 19.70],
     "SLC": [-114.25, 36.80, -109.67, 42.20],
-    "STO": [-123.29, 36.93, -119.40, 41.38],
-    "TAE": [-86.59, 29.09, -82.68, 32.19],
-    "TBW": [-83.37, 26.12, -80.74, 29.79],
+    "STO": [-123.27, 36.93, -119.40, 41.38],
+    "STU": [-171.92, -15.25, -168.55, -10.21],
+    "TAE": [-86.60, 28.38, -82.68, 32.19],
+    "TBW": [-84.25, 25.77, -80.74, 29.79],
     "TFX": [-114.27, 44.16, -108.04, 49.20],
     "TOP": [-98.13, 37.84, -94.86, 40.20],
     "TSA": [-97.26, 33.67, -93.10, 37.20],
