@@ -1,17 +1,44 @@
 """PIREP."""
-# pylint: disable=redefined-outer-name
 
 import pytest
 from pyiem.nws.products.pirep import parser as pirepparser
-from pyiem.util import utc, get_test_file, get_dbconn
+from pyiem.util import utc, get_test_file
 
 
-@pytest.fixture()
-def dbcursor():
-    """Get a database cursor."""
-    return get_dbconn("postgis").cursor()
+def test_210121_int_latlon():
+    """Test successful parsing of an integer lat lon value, tricky."""
+    utcnow = utc(2020, 1, 21, 10, 22)
+    prod = pirepparser(get_test_file("PIREPS/latlonint.txt"), utcnow=utcnow)
+    assert prod.reports[0].latitude == 47
+    assert prod.reports[0].longitude == -51
 
 
+def test_210110_canada():
+    """Test that generated error is for canada site id."""
+    utcnow = utc(2020, 1, 11, 3, 47)
+    prod = pirepparser(get_test_file("PIREPS/canada.txt"), utcnow=utcnow)
+    assert "CYAT" in prod.warnings[0]
+
+
+@pytest.mark.parametrize("database", ["postgis"])
+def test_210108_emptygeom(dbcursor):
+    """Test that we insert empty geometries."""
+    utcnow = utc(2020, 1, 1, 21, 34)
+    prod = pirepparser(get_test_file("PIREPS/badgeom.txt"), utcnow=utcnow)
+    prod.reports[3].is_duplicate = True
+    prod.assign_cwsu(dbcursor)
+    prod.sql(dbcursor)
+    prod.get_jabbers("")
+    assert len(prod.reports) == 6
+    dbcursor.execute(
+        "SELECT count(*) from pireps where valid = %s and "
+        "ST_IsEmpty(geom::geometry)",
+        (utcnow,),
+    )
+    assert dbcursor.fetchone()[0] >= 1
+
+
+@pytest.mark.parametrize("database", ["postgis"])
 def test_180307_aviation_controlchar(dbcursor):
     """Darn Aviation control character showing up in WMO products"""
     nwsli_provider = {"BWI": {"lat": 44.26, "lon": -88.52}}
@@ -19,6 +46,7 @@ def test_180307_aviation_controlchar(dbcursor):
         get_test_file("PIREPS/ubmd90.txt"), nwsli_provider=nwsli_provider
     )
     assert len(prod.reports) == 1
+    prod.assign_cwsu(dbcursor)
     prod.sql(dbcursor)
 
 
@@ -57,7 +85,7 @@ def test_151210_badgeom():
     prod = pirepparser(
         get_test_file("PIREPS/badgeom.txt"), nwsli_provider=nwsli_provider
     )
-    assert not prod.reports
+    assert prod.reports[0].latitude is None
 
 
 def test_150202_groupdict():
@@ -66,7 +94,7 @@ def test_150202_groupdict():
     prod = pirepparser(
         get_test_file("PIREPS/groupdict.txt"), nwsli_provider=nwsli_provider
     )
-    assert len(prod.reports) == 1
+    assert len(prod.reports) == 6
 
 
 def test_150202_airmet():
@@ -192,7 +220,9 @@ def test_1():
     utcnow = utc(2015, 1, 9, 0, 0)
     nwsli_provider = {
         "BIL": {"lat": 44, "lon": 99},
+        "PIB": {"lat": 44, "lon": 99},
         "LBY": {"lat": 45, "lon": 100},
+        "MBO": {"lat": 45, "lon": 100},
         "PUB": {"lat": 46, "lon": 101},
         "HPW": {"lat": 47, "lon": 102},
     }
