@@ -30,6 +30,47 @@ def filter_warnings(ar, startswith="get_gid"):
     return [a for a in ar if not a.startswith(startswith)]
 
 
+@pytest.mark.parametrize("database", ["postgis"])
+def test_issue253_ibwthunderstorm(dbcursor):
+    """Test the processing of IBW Thunderstorm Damage Threat."""
+    data = get_test_file("SVR/SVRPSR_IBW1.txt")
+    prod = vtecparser(data)
+    prod.sql(dbcursor)
+    dbcursor.execute(
+        "select damagetag from sbw_2020 where wfo = 'PSR' "
+        "and eventid = 43 and phenomena = 'SV' and significance = 'W' "
+    )
+    assert dbcursor.fetchone()[0] == "CONSIDERABLE"
+    j = prod.get_jabbers("")
+    ans = (
+        "PSR issues Severe Thunderstorm Warning [tornado: POSSIBLE, "
+        "damage threat: CONSIDERABLE, wind: 70 MPH (OBSERVED), "
+        "hail: 1.00 IN (RADAR INDICATED)] for "
+        "((AZC013)), ((AZC021)) [AZ] till 6:00 PM MST "
+        "2020-O-NEW-KPSR-SV-W-0043_2020-09-09T00:29Z"
+    )
+    assert j[0][0] == ans
+
+
+def test_210304_notimezone():
+    """Test that we not care that this product has no local timezone."""
+    data = get_test_file("TSU/TSUPAC.txt")
+    prod = vtecparser(data)
+    assert not prod.warnings
+    assert prod.valid == utc(2021, 3, 4, 18, 58)
+    prod = vtecparser(data.replace("1858", "0048"))
+    assert not prod.warnings
+    assert prod.valid == utc(2021, 3, 4, 0, 48)
+
+
+@pytest.mark.parametrize("database", ["postgis"])
+def test_210302_multipolygon(dbcursor):
+    """Test that buffer(0) producing a multipolygon is culled."""
+    prod = vtecparser(get_test_file("FLW/FLWJKL_multipolygon.txt"))
+    prod.sql(dbcursor)
+    assert any(["culling" in x for x in prod.warnings])
+
+
 @pytest.mark.parametrize("database", ["postgis"])
 def test_210103_vtec_cor(dbcursor):
     """Test that VTEC COR actions do not get their status stored."""
@@ -213,12 +254,22 @@ def test_200719_nomnd():
 @pytest.mark.parametrize("database", ["postgis"])
 def test_200306_issue210(dbcursor):
     """Test our logic for figuring out which table has our event."""
+    nwsli_provider = {
+        "JAMS1": NWSLI("JAMS1", "Ames", ["XXX"], -99, 44),
+        "CNOG1": NWSLI("CNOG1", "Ames", ["XXX"], -99, 44),
+    }
     for i in range(7):
-        prod = vtecparser(get_test_file("FLWCHS/2019_%s.txt" % (i,)))
+        prod = vtecparser(
+            get_test_file("FLWCHS/2019_%s.txt" % (i,)),
+            nwsli_provider=nwsli_provider,
+        )
         prod.sql(dbcursor)
         assert not filter_warnings(prod.warnings)
     for i in range(2):
-        prod = vtecparser(get_test_file("FLWCHS/2020_%s.txt" % (i,)))
+        prod = vtecparser(
+            get_test_file("FLWCHS/2020_%s.txt" % (i,)),
+            nwsli_provider=nwsli_provider,
+        )
         prod.sql(dbcursor)
         assert not filter_warnings(prod.warnings)
 
@@ -232,10 +283,10 @@ def test_200302_issue203(dbcursor):
         if i == 0:
             assert prod.segments[0].sbw
             continue
-        assert prod.warnings[0].find("should have contained") > -1
+        assert prod.warnings[1].find("should have contained") > -1
         assert prod.segments[0].sbw is None
         assert prod.segments[0].is_pds is False
-        assert len(prod.warnings) == 2
+        assert len(prod.warnings) == 3
         dbcursor.execute(
             """
             SELECT status from sbw_2020 WHERE wfo = 'CAE' and
@@ -366,7 +417,11 @@ def test_181228_issue76_sbwtable(dbcursor):
     """Can we locate the current SBW table with polys in the future."""
     prod = vtecparser(get_test_file("FLWMOB/FLW.txt"))
     prod.sql(dbcursor)
-    prod = vtecparser(get_test_file("FLWMOB/FLS.txt"))
+    assert "HVTEC NWSLI MRRM6 is unknown." in prod.warnings
+    prod = vtecparser(
+        get_test_file("FLWMOB/FLS.txt"),
+        nwsli_provider={"MRRM6": NWSLI("MRRM6", "Ames", ["XXX"], -99, 44)},
+    )
     prod.sql(dbcursor)
     dbcursor.execute(
         "SELECT * from sbw_2018 where wfo = 'MOB' and eventid = 57 "
@@ -593,7 +648,7 @@ def test_170324_waterspout(dbcursor):
 def test_170303_ccwpoly():
     """Test that CCW polygon does not trip us up."""
     prod = vtecparser(get_test_file("FLWHGX_ccw.txt"))
-    assert not filter_warnings(prod.warnings)
+    assert not filter_warnings(filter_warnings(prod.warnings), "HVTEC")
 
 
 @pytest.mark.parametrize("database", ["postgis"])
@@ -684,7 +739,7 @@ def test_151225_extfuture(dbcursor):
     prod = vtecparser(get_test_file("FLWPAH/FLWPAH_2.txt"))
     prod.sql(dbcursor)
     warnings = filter_warnings(filter_warnings(prod.warnings), CUGC)
-    assert len(warnings) == 1
+    assert len(warnings) == 2
 
 
 @pytest.mark.parametrize("database", ["postgis"])
@@ -802,11 +857,11 @@ def test_150115_correction_sbw(dbcursor):
     """ FLWMHX make sure a correction does not result in two polygons """
     prod = vtecparser(get_test_file("FLWMHX/0.txt"))
     prod.sql(dbcursor)
-    warnings = filter_warnings(prod.warnings)
+    warnings = filter_warnings(filter_warnings(prod.warnings), "HVTEC")
     assert not warnings
     prod = vtecparser(get_test_file("FLWMHX/1.txt"))
     prod.sql(dbcursor)
-    warnings = filter_warnings(prod.warnings)
+    warnings = filter_warnings(filter_warnings(prod.warnings), "HVTEC")
     assert not warnings
 
 
@@ -816,7 +871,7 @@ def test_150105_considerable_tag():
     j = prod.get_jabbers("http://localhost", "http://localhost")
     ans = (
         "FSD issues Tornado Warning (PDS) "
-        "[tornado: RADAR INDICATED, tornado damage threat: CONSIDERABLE, "
+        "[tornado: RADAR INDICATED, damage threat: CONSIDERABLE, "
         "hail: 1.50 IN] for ((IAC035)) [IA] till 8:00 PM CDT * AT 720 "
         "PM CDT...A SEVERE THUNDERSTORM CAPABLE OF PRODUCING A LARGE "
         "AND EXTREMELY DANGEROUS TORNADO WAS LOCATED NEAR WASHTA...AND "
@@ -937,7 +992,7 @@ def test_141211_null_expire(dbcursor):
         print("Parsing Product: %s.txt" % (i,))
         prod = vtecparser(get_test_file("FLSIND/%i.txt" % (i,)))
         prod.sql(dbcursor)
-        warnings = filter_warnings(prod.warnings)
+        warnings = filter_warnings(filter_warnings(prod.warnings), "HVTEC")
         assert not filter_warnings(warnings, "LAT...LON")
 
 
@@ -947,7 +1002,7 @@ def test_141210_continues(dbcursor):
     for i in range(0, 2):
         prod = vtecparser(get_test_file("FFAEKA/%i.txt" % (i,)))
         prod.sql(dbcursor)
-        warnings = filter_warnings(prod.warnings)
+        warnings = filter_warnings(filter_warnings(prod.warnings), "HVTEC")
         assert not warnings
 
 
@@ -1012,7 +1067,7 @@ def test_tornado_emergency():
         '<p>ICT <a href="http://localhost'
         '2012-O-NEW-KICT-TO-W-0035_2012-04-15T03:27Z">'
         "issues Tornado Emergency</a> "
-        "[tornado: OBSERVED, tornado damage threat: CATASTROPHIC, "
+        "[tornado: OBSERVED, damage threat: CATASTROPHIC, "
         "hail: 2.50 IN] for ((KSC015)), ((KSC173)) [KS] till 11:00 PM CDT "
         '* AT 1019 PM CDT...<span style="color: #FF0000;">TORNADO '
         "EMERGENCY</span> FOR THE WICHITA METRO AREA. A CONFIRMED LARGE..."
@@ -1021,7 +1076,7 @@ def test_tornado_emergency():
     )
     assert j[0][1] == ans
     ans = (
-        "ICT issues Tornado Emergency [tornado: OBSERVED, tornado damage "
+        "ICT issues Tornado Emergency [tornado: OBSERVED, damage "
         "threat: CATASTROPHIC, hail: 2.50 IN] "
         "for ((KSC015)), ((KSC173)) [KS] till 11:00 PM CDT "
         "http://localhost2012-O-NEW-KICT-TO-W-0035_2012-04-15T03:27Z"
@@ -1124,7 +1179,7 @@ def test_routine(dbcursor):
     utcnow = utc(2014, 6, 19, 2, 56)
     prod = vtecparser(get_test_file("FLWMKX_ROU.txt"), utcnow=utcnow)
     prod.sql(dbcursor)
-    warnings = filter_warnings(prod.warnings)
+    warnings = filter_warnings(filter_warnings(prod.warnings), "HVTEC")
     assert not warnings
 
 
@@ -1233,7 +1288,7 @@ def test_tortag():
         '<p>DMX <a href="http://localhost/2011-'
         'O-NEW-KDMX-TO-W-0057_2011-08-07T04:36Z">'
         "issues Tornado Warning</a> [tornado: "
-        "OBSERVED, tornado damage threat: SIGNIFICANT, hail: 2.75 IN] "
+        "OBSERVED, damage threat: SIGNIFICANT, hail: 2.75 IN] "
         "for ((IAC117)), ((IAC125)), ((IAC135)) [IA] till 12:15 AM CDT "
         "* AT 1132 PM CDT...NATIONAL WEATHER SERVICE DOPPLER RADAR "
         "INDICATED A SEVERE THUNDERSTORM CAPABLE OF PRODUCING A TORNADO. "
