@@ -37,7 +37,7 @@ def test_180917_issue63_tweet_length():
         "At 6:45 AM CDT, 2 NNE Odem [San Patricio Co, TX] DEPT OF HIGHWAYS "
         "reports FLOOD. ROAD CLOSURE FM 1944 BETWEEN U.S. HIGHWAY 77 AND "
         "SODVILLE ROAD (TEXAS DEPARTMENT OF TRANSPORATION. DRIVETEXAS.ORG.) "
-        "LATITUDE/LONGITUDE MARKS APPROXIMATE POSITION OF FM 194... "
+        "LATITUDE/LONGITUDE MARKS APPROXIMATE POSITION OF FM 19... "
         "http://iem.local/#CRP/201809151145/201809151145"
     )
 
@@ -179,7 +179,7 @@ def test_150422_tornadomag():
         "4 W Bruce [Walton Co, FL] NWS EMPLOYEE reports "
         "TORNADO of EF0. SHORT EF0 TORNADO PATH CONFIRMED BY NWS DUAL "
         "POL RADAR DEBRIS SIGNATURE IN A RURAL AREA WEST OF BRUCE. "
-        "DAMAGE LIKELY CONFINED TO TREES. ESTIMATED... "
+        "DAMAGE LIKELY CONFINED TO TREES. ESTIMATE... "
         "http://iem.local/#TAE/201504191322/201504191322"
     )
 
