@@ -18,6 +18,7 @@ from pyiem.plot import (
     load_pickle_pd,
     load_pickle_geo,
 )
+from pyiem.util import utc
 
 
 def test_depreciated():
@@ -33,6 +34,126 @@ def test_invalid_file():
     assert not load_pickle_geo("this shall not work")
 
 
+@pytest.mark.mpl_image_compare(tolerance=0.1)
+def test_issue374_pah():
+    """Test drawing fire weather zones for Paducah."""
+    mp = MapPlot(
+        nocaption=True,
+        sector="cwa",
+        cwa="PAH",
+        title="Paducah Fire Weather Zones including MOZ098 Shannon",
+    )
+    mp.fill_ugcs({"MOZ098": 10}, is_firewx=True)
+    return mp.fig
+
+
+@pytest.mark.mpl_image_compare(tolerance=0.1)
+def test_memphis_cwa():
+    """Test that we can draw a map with Memphis CWA.."""
+    mp = MapPlot(
+        nocaption=True,
+        sector="cwa",
+        cwa="MEG",
+        title="Memphis including Hardin, TN TNZ092",
+    )
+    mp.fill_ugcs({"TNZ092": 10})
+    return mp.fig
+
+
+@pytest.mark.mpl_image_compare(tolerance=0.1)
+def test_overlay_roadcond():
+    """Test being able to plot Iowa Road Conditions."""
+    mp = MapPlot(
+        nocaption=True,
+        sector="iowa",
+        title="A long and long title that has no purpose but to test things",
+    )
+    mp.overlay_roadcond(utc(2021, 2, 4, 17))
+    return mp.fig
+
+
+@pytest.mark.mpl_image_compare(tolerance=0.1)
+def test_overlay_nexrad():
+    """Test being able to plot NEXRAD."""
+    mp = MapPlot(
+        nocaption=True,
+        sector="conus",
+        title="A long and long title that has no purpose but to test things",
+    )
+    mp.overlay_nexrad(utc(2021, 2, 9, 17))
+    return mp.fig
+
+
+@pytest.mark.mpl_image_compare(tolerance=0.1)
+def test_overlay_nexrad_hawaii():
+    """Test that we can plot nexrad over Hawaii."""
+    mp = MapPlot(
+        nocaption=True,
+        sector="state",
+        state="HI",
+        title="A long and long title that has no purpose but to test things",
+    )
+    mp.overlay_nexrad(utc(2021, 2, 9, 17))
+    return mp.fig
+
+
+@pytest.mark.mpl_image_compare(tolerance=0.1)
+def test_overlay_nexrad_alaska():
+    """Test that we can plot nexrad over Alaska."""
+    mp = MapPlot(
+        nocaption=True,
+        sector="cwa",
+        cwa="AJK",
+        title="A long and long title that has no purpose but to test things",
+    )
+    mp.overlay_nexrad(utc(2021, 2, 9, 17))
+    return mp.fig
+
+
+@pytest.mark.mpl_image_compare(tolerance=0.1)
+def test_overlay_nexrad_puerto_rico():
+    """Test that we can plot nexrad over Puerto Rico."""
+    mp = MapPlot(
+        nocaption=True,
+        sector="cwa",
+        cwa="SJU",
+        title="A long and long title that has no purpose but to test things",
+    )
+    mp.overlay_nexrad(utc(2021, 2, 9, 17))
+    return mp.fig
+
+
+@pytest.mark.mpl_image_compare(tolerance=0.1)
+def test_conus_contour():
+    """Test that a conus sector plot can generate a contour correctly."""
+    mp = MapPlot(nocaption=True, sector="conus", twitter=True)
+    mp.contourf(
+        np.arange(-120, -47, 3),
+        np.arange(25, 50),
+        np.arange(25),
+        np.arange(25),
+        clip_on=False,
+    )
+    mp.draw_mask(sector="conus")
+    return mp.fig
+
+
+@pytest.mark.mpl_image_compare(tolerance=0.1)
+def test_issue365_cape_cod():
+    """Test that we don't mask out Cape Cod."""
+    mp = MapPlot(nocaption=True, sector="cwa", cwa="BOX")
+    mp.contourf(
+        np.arange(-75, -66),
+        np.arange(36, 45),
+        np.arange(9),
+        np.arange(9),
+        clevlabels=["a", "b", "c", "d", "e", "f", "g", "h", "i"],
+        clip_on=False,
+    )
+    mp.draw_mask(sector="conus")
+    return mp.fig
+
+
 @pytest.mark.mpl_image_compare(tolerance=0.1)
 def test_issue217():
     """See what happens with our logo on very scaled figure."""
@@ -446,7 +567,7 @@ def test_ugcs_lwx_zones():
     mp = MapPlot(
         sector="cwa",
         cwa="LWX",
-        title="Two Maryland Counties",
+        title="Two Maryland Zones that Should not be plotted",
         subtitle="test_ugcs_lwx",
         nocaption=True,
     )
@@ -534,6 +655,7 @@ def test_cwa():
         clevlabels=["a", "b", "c", "d", "e"],
     )
     mp.draw_cwas()
+    mp.drawcounties()
     assert mp.cwa == "MKX"
     return mp.fig
 
