@@ -5,7 +5,9 @@ We use a pickled protocol=2, which is compat binary.
 import datetime
 
 import pickle
+from shapely.geometry import MultiPolygon
 from shapely.wkb import loads
+from geopandas import read_postgis
 from pyiem.util import get_dbconn
 
 PATH = "../src/pyiem/data"
@@ -13,6 +15,29 @@ PATH = "../src/pyiem/data"
 print("Be sure to run this against Mesonet database and not laptop!")
 
 
+def dump_conus(fn):
+    """states."""
+    pgconn = get_dbconn("postgis", user="nobody")
+
+    df = read_postgis(
+        """SELECT
+            ST_Transform(
+                ST_Simplify(
+                    ST_Union(ST_Transform(the_geom,2163)),
+                    500.),
+                4326) as geo from states
+        WHERE state_abbr not in ('HI', 'AK', 'PR')""",
+        pgconn,
+        geom_col="geo",
+    )
+    # Now we want to filter out some smaller geometries
+    mp = MultiPolygon([geo for geo in df["geo"].values[0] if geo.area > 0.002])
+    data = {}
+    data["conus"] = dict(geom=mp, lon=mp.centroid.x, lat=mp.centroid.y)
+    with open("%s/%s" % (PATH, fn), "wb") as f:
+        pickle.dump(data, f, 2)
+
+
 def dump_states(fn):
     """states."""
     pgconn = get_dbconn("postgis", user="nobody")
@@ -98,16 +123,21 @@ def dump_iowawfo(fn):
         pickle.dump(data, f, 2)
 
 
-def dump_ugc(gtype, fn):
+def dump_ugc(gtype, fn, is_firewx=False):
     """UGCS."""
     pgconn = get_dbconn("postgis", user="nobody")
     cursor = pgconn.cursor()
 
+    source_limiter = "source != 'fz'"
+    if is_firewx:
+        source_limiter = "source = 'fz'"
+
     # We want UGCs valid for the time of running this script
     cursor.execute(
         "SELECT ugc, wfo, simple_geom, ST_x(centroid), ST_Y(centroid) "
         "from ugcs WHERE begin_ts < now() and "
-        "(end_ts is null or end_ts > now()) and substr(ugc, 3, 1) = %s",
+        "(end_ts is null or end_ts > now()) and substr(ugc, 3, 1) = %s "
+        f"and {source_limiter}",
         (gtype,),
     )
 
@@ -140,11 +170,15 @@ def check_file(fn):
 
 def main():
     """Go Main"""
+    dump_conus("conus.pickle")
+    check_file("conus.pickle")
     dump_iowawfo("iowawfo.pickle")
     dump_ugc("C", "ugcs_county.pickle")
-    dump_ugc("Z", "ugcs_zone.pickle")
+    dump_ugc("Z", "ugcs_zone.pickle", is_firewx=False)
+    dump_ugc("Z", "ugcs_firewx.pickle", is_firewx=True)
     check_file("ugcs_county.pickle")
     check_file("ugcs_zone.pickle")
+    check_file("ugcs_firewx.pickle")
     dump_cwa("cwa.pickle")
     check_file("cwa.pickle")
     dump_climdiv("climdiv.pickle")
